//@line 36 "/builds/tinderbox/Sb-Mozilla1.8-l10n/Linux_2.4.21-37.EL_Clobber/mozilla/calendar/sunbird/locales/../../../../l10n/de/calendar/sunbird-l10n.js"

//@line 38 "/builds/tinderbox/Sb-Mozilla1.8-l10n/Linux_2.4.21-37.EL_Clobber/mozilla/calendar/sunbird/locales/../../../../l10n/de/calendar/sunbird-l10n.js"

//@line 41 "/builds/tinderbox/Sb-Mozilla1.8-l10n/Linux_2.4.21-37.EL_Clobber/mozilla/calendar/sunbird/locales/../../../../l10n/de/calendar/sunbird-l10n.js"
pref("calendar.week.start", 1);                                                 

//@line 44 "/builds/tinderbox/Sb-Mozilla1.8-l10n/Linux_2.4.21-37.EL_Clobber/mozilla/calendar/sunbird/locales/../../../../l10n/de/calendar/sunbird-l10n.js"
pref("calendar.week.d0sundaysoff", true);                                       
pref("calendar.week.d1mondaysoff", false);                                      
pref("calendar.week.d2tuesdaysoff", false);                                     
pref("calendar.week.d3wednesdaysoff", false);                                   
pref("calendar.week.d4thursdaysoff", false);                                    
pref("calendar.week.d5fridaysoff", false);                                      
pref("calendar.week.d6saturdaysoff", true);                                     

pref("general.useragent.locale", "de");

//@line 55 "/builds/tinderbox/Sb-Mozilla1.8-l10n/Linux_2.4.21-37.EL_Clobber/mozilla/calendar/sunbird/locales/../../../../l10n/de/calendar/sunbird-l10n.js"
pref("calendar.categories.names", "Jubiläum,Geburtstag,Geschäft,Anrufe,Klienten,Konkurrenz,Kunde,Favoriten,Nachgehen,Geschenke,Ferien,Ideen,Fragen,Verschiedenes,Persönlich,Projekte,Feiertag,Status,Lieferanten,Reise,Urlaub");
